@@ -4,24 +4,28 @@ from statistics import mean, stdev
 from typing import List
 
 def average(elements: List[float]) -> float:
+    elements = [elem for elem in elements if elem is not None]
     if len(elements) == 0:
-        return 0
+        return None
     return mean(elements)
 
 def standard_deviation(elements: List[float]) -> float:
+    elements = [elem for elem in elements if elem is not None]
     if len(elements) == 0:
-        return 0
+        return None
     elif len(elements) == 1:
         return 0
     return stdev(elements)
 
 def maximum(elements: List[float]) -> float:
+    elements = [elem for elem in elements if elem is not None]
     if len(elements) == 0:
-        return 0
+        return None
     return max(elements)
 
 
 class MeasureFunction(Enum):
     AVG = average
     STDEV = standard_deviation
-    MAX = maximum
\ No newline at end of file
+    MAX = maximum
+    IDENTITY = lambda x: x
\ No newline at end of file
